<?php
/*
Plugin Name: Protección de datos - RGPD
Plugin URI:  https://taller.abcdatos.net/plugin-rgpd-wordpress/
Description: Arrange your site to GDPR (General Data Protection Regulation) and LSSICE as well as other required tasks based on required configurations ettings.
Version:     0.43
Author:      ABCdatos
Author URI:  https://taller.abcdatos.net/
License:     GPLv2
License URI: https://www.gnu.org/licenses/gpl-2.0.html
Text Domain: proteccion-datos-rgpd
Domain Path: /languages
*/

defined( 'ABSPATH' ) or die( 'No se permite el acceso.' );

# i18n
# O usamos este hook o el requisito mínimo es WP 4.6
add_action( 'plugins_loaded', 'pdrgpd_load_plugin_textdomain' );
function pdrgpd_load_plugin_textdomain() {
	load_plugin_textdomain( 'proteccion-datos-rgpd', FALSE, basename( dirname( __FILE__ ) ) . '/languages' );
}

// Administration features (settings)
if ( is_admin() ) {
	include_once( 'admin/options.php' );
}

// Legal Advice related code loading
include_once( plugin_dir_path( __FILE__ ) . 'aviso-legal.php' );

// Privacy Policy related code loading
include_once( plugin_dir_path( __FILE__ ) . 'politica-privacidad.php' );

// Primera capa del deber de información y casilla de aceptación en formularios
include_once( plugin_dir_path( __FILE__ ) . 'formularios.php' );

// Cookie Policy related code loading
include_once( plugin_dir_path( __FILE__ ) . 'politica-cookies.php' );

// Notas a pie de página
include_once( plugin_dir_path( __FILE__ ) . 'pie.php' );

// Lista de variables usadas en tabla options
function lista_opciones() {
	return array(
		'pdrgpd_version',
		'pdrgpd_titular',
		'pdrgpd_nif',
		'pdrgpd_direccion',
		'pdrgpd_cp',
		'pdrgpd_poblacion',
		'pdrgpd_provincia',
		'pdrgpd_telefono',
		'pdrgpd_email',
		'pdrgpd_rmercant_poblacion',
		'pdrgpd_rmercant_provincia',
		'pdrgpd_rmercant_libro',
		'pdrgpd_rmercant_tomo',
		'pdrgpd_rmercant_folio',
		'pdrgpd_rmercant_hoja',
		'pdrgpd_rmercant_num',
		'pdrgpd_sitio',
		'pdrgpd_dominio',
		'pdrgpd_uri_aviso',
		'pdrgpd_uri_privacidad',
		'pdrgpd_uri_cookies',
		'pdrgpd_existencia_formulario_contacto',
		'pdrgpd_finalidad_formulario_contacto_mini',
		'pdrgpd_finalidad_formulario_contacto',
		'pdrgpd_existencia_boletin',
		'pdrgpd_finalidad_suscripcion_boletin_mini',
		'pdrgpd_finalidad_suscripcion_boletin',
		'pdrgpd_aplicar_formulario_comentar',
		'pdrgpd_finalidad_formulario_comentar_mini',
		'pdrgpd_finalidad_formulario_comentar',
		'pdrgpd_pie_enlace_legal',
		'pdrgpd_pie_enlace_privacidad',
		'pdrgpd_pie_enlace_cookies',
		'pdrgpd_pie_copyright',
		'pdrgpd_pie_multilinea',
		'pdrgpd_formato_primera_capa'
	);
}

// Settings link in Plugins admin page
// Based on https://www.smashingmagazine.com/2011/03/ten-things-every-wordpress-plugin-developer-should-know/
add_filter( 'plugin_action_links' , 'pdrgpd_plugin_action_links' , 10 , 2 );
function pdrgpd_plugin_action_links( $links , $file ) {
	static $this_plugin;
	if ( ! $this_plugin ) {
		$this_plugin = plugin_basename( __FILE__ );
	}
	if ( $file == $this_plugin ) {
		// The "page" query string value must be equal to the slug of the Settings admin page
		$settings_link = '<a href="' . admin_url( 'admin.php?page=proteccion-datos-rgpd' ) . '">' . __( 'Settings' ) . '</a>';
		array_unshift( $links , $settings_link );
	}
	return $links;
}

// Plugin version for options page header.
function pdrgpd_get_version() {
	$plugin_data = get_plugin_data( __FILE__ );
	$plugin_version = $plugin_data['Version'];
	return $plugin_version;
}

// Common functions
function pdrgpd_nif_o_cif( $codigo ) {
	// Determina si es NIF, CIF o NIE por la sintaxis
	$tipo = 'DNI';
	if ( preg_match( '/^[a-z]/i' , $codigo ) ) {
		$tipo = 'CIF';
		if ( preg_match( '/^(x|y|z)/i' , $codigo ) ) {
			$tipo = 'NIE';
		}
	}
	return $tipo;
}
